@@ -15,7 +15,7 @@ use Params::Validate ();
 # and one which has compile errors.
 use Module::Find qw( );
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use overload
   '%{}'    => '_envhash',
@@ -75,34 +75,34 @@ use constant APP_ENV_SITE => do {
       && length $ENV{APP_ENV_SITE} ? $ENV{APP_ENV_SITE} : undef;
 };
 
+# _App_Env_Site ( [$alt_site] );
 # if $alt_site is non-empty, return it.
-# if $alt_site is empty, return ().
-# if $alt_site is undefined, return APP_ENV_SITE
+# if $alt_site is empty or undefined return ().
+# otherwise return APP_ENV_SITE
 sub _App_Env_Site {
+
+    @_ || return APP_ENV_SITE;
+
     my $site = shift;
 
+    return () if !defined $site || $site eq '';
+    return $site;
+
 # _croak( "Environment variable APP_ENV_SITE is only obeyed at the time that ${ \__PACKAGE__ } is loaded" )
 #   if ( defined( APP_ENV_SITE ) xor defined $ENV{APP_ENV_SITE} )
 #   || ( defined( APP_ENV_SITE ) && defined $ENV{APP_ENV_SITE} && APP_ENV_SITE ne $ENV{APP_ENV_SITE} );
-
-    return
-        defined $site
-      ? length( $site )
-          ? $site
-          : ()
-      : APP_ENV_SITE;
 }
 
 #-------------------------------------------------------
 
 # Options
 my %SharedOptions = (
-    Force    => { default => 0 },
-    Cache    => { default => 1 },
-    Site     => { default => undef },
-    CacheID  => { default => undef },
-    Temp     => { default => 0 },
-    SysFatal => { default => 0, type => Params::Validate::BOOLEAN },
+    Force    => { default  => 0 },
+    Cache    => { default  => 1 },
+    Site     => { optional => 1 },
+    CacheID  => { default  => undef },
+    Temp     => { default  => 0 },
+    SysFatal => { default  => 0, type => Params::Validate::BOOLEAN },
 );
 
 my %ApplicationOptions = (
@@ -480,10 +480,10 @@ sub uncache {
     my %opt = Params::Validate::validate(
         @_,
         {
-            All     => { default => undef, type => Params::Validate::SCALAR },
-            App     => { default => undef, type => Params::Validate::SCALAR },
-            Site    => { default => undef, type => Params::Validate::SCALAR },
-            CacheID => { default => undef, type => Params::Validate::SCALAR },
+            All     => { default  => undef, type => Params::Validate::SCALAR },
+            App     => { default  => undef, type => Params::Validate::SCALAR },
+            Site    => { optional => 1,     type => Params::Validate::SCALAR },
+            CacheID => { default  => undef, type => Params::Validate::SCALAR },
         } );
 
     if ( $opt{All} ) {
@@ -507,8 +507,10 @@ sub uncache {
 
         # don't use normal rules for Site specification as we're trying
         # to delete a specific one.
-        delete $EnvCache{ _modulename( _App_Env_Site( $opt{Site} ), $opt{App} )
-        };
+        delete $EnvCache{
+            _modulename(
+                _App_Env_Site( exists $opt{Site} ? ( $opt{Site} ) : () ),
+                $opt{App} ) };
     }
 
     return;
@@ -528,15 +530,15 @@ sub _modulename {
 # found, false if not, die's if require fails
 
 sub _require_module {
-    my ( $app, $usite, $loop, $app_opts ) = @_;
+    my ( $app, %par ) = @_;
 
-    $app_opts ||= {};
+    my $app_opts = $par{app_opts} ||= {};
+    my $loop     = $par{loop}     ||= 1;
 
-    $loop ||= 1;
     _croak( "too many alias loops for $app\n" )
       if $loop == 10;
 
-    my @sites = _App_Env_Site( $usite );
+    my @sites = _App_Env_Site( exists $par{site} ? $par{site} : () );
 
     # check possible sites, in turn.
     my ( $module )
@@ -554,7 +556,11 @@ sub _require_module {
             ( $app, my $napp_opts ) = $alias->();
             @{$app_opts}{ keys %$napp_opts } = @{$napp_opts}{ keys %$napp_opts }
               if $napp_opts;
-            return _require_module( $app, $usite, ++$loop, $app_opts );
+            return _require_module(
+                $app, %par,
+                loop     => ++$loop,
+                app_opts => $app_opts
+            );
         }
     }
 
@@ -866,8 +872,14 @@ sub new {
     }
     else {
 
-        ( $self->{module}, my $app_opts )
-          = eval { App::Env::_require_module( $self->{app}, $self->{opt}{Site} ) };
+        ( $self->{module}, my $app_opts ) = eval {
+            App::Env::_require_module(
+                $self->{app},
+                (
+                    exists $self->{opt}{Site}
+                    ? ( site => $self->{opt}{Site} )
+                    : () ) );
+        };
 
         _croak(
             ref $@
@@ -1024,7 +1036,7 @@ App::Env - manage application specific environments
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -1299,7 +1311,12 @@ Don't use the cached environment for this application.
 
 =item Site
 
-Specify a site.  See L</Application Environments> for more information
+Specify a site.  See L</Application Environments> for more
+information.  Set this to C<undef> or the empty string C<''> to ignore
+(rather than replace) the default site.  For example, if the default
+site is C<Site1>, then setting C<< $application = 'MyApp' >> and C<<
+Site => undef >> will clear load C<App::Env::MyApp>, not
+C<App::Env::Site1::MyApp>.
 
 =item Cache I<boolean>
 
@@ -1381,6 +1398,12 @@ If the B<Site> option was used when first loading the environment,
 it must be specified here in order to delete the correct cache entry.
 Do not specify this option if B<CacheID> is specified.
 
+Setting C<Site> to C<undef> or the empty string C<''> will
+ignore (rather than replace) the default site setting.  For example, if the default site is
+C<Site1>, then setting C<< App => 'MyApp', Site => undef >> will clear
+the cache for C<App::Env::MyApp> rather than
+C<App::Env::Site1::MyApp>.
+
 =item CacheID
 
 If the B<CacheID> option was used to provide a cache key for the cache
