@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 sub alias {
-    return 'App3', { Alias => 'App4' }
-};
+    return 'App3', { Alias => 'App4' };
+}
 
 1;
